@@ -4,9 +4,9 @@
  * GChemPaint
  * elementtool.cc 
  *
- * Copyright (C) 2001-2003
+ * Copyright (C) 2001-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -55,7 +55,7 @@ bool gcpElementTool::OnClicked()
 	if (m_pObject)
 	{
 		if (m_pObject->GetType() != AtomType) return false; 
-		if 	(((gcpAtom*)m_pObject)->GetTotalBondsNumber() > Element::GetMaxBonds(CurZ)) return false;
+		if 	((unsigned) ((gcpAtom*)m_pObject)->GetTotalBondsNumber() > Element::GetMaxBonds(CurZ)) return false;
 		((gcpAtom*)m_pObject)->GetCoords(&m_x0, &m_y0);
 		m_x0 *= m_dZoomFactor;
 		m_y0 *= m_dZoomFactor;
