@@ -4,9 +4,9 @@
  * GChemPaint
  * main.cc 
  *
- * Copyright (C) 2001-2004
+ * Copyright (C) 2001-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -65,6 +65,10 @@ static GtkMenu *windowsmenu;
 static GtkWidget* bar;	//GnomeAppBar
 static map<string, string> SupportedPixbufFormats;
 
+#ifndef GTK_IS_26
+GdkPixbuf *icon;
+#endif
+
 void on_change_element(int Z)
 {
 	CurElt = Z;
@@ -199,9 +203,10 @@ void on_print(GtkWidget* widget, void* data)
 	GnomePrintConfig* config = gnome_print_config_default();
 	GnomePrintContext *pc;// = gnome_print_context_new(config);
 	GnomePrintJob *gpj = gnome_print_job_new(config);
-	int do_preview, copies = 1, collate = 0;
+	int do_preview = 0, copies = 1, collate = 0;
 	GnomePrintDialog *gpd;
 	gpd = GNOME_PRINT_DIALOG (gnome_print_dialog_new(gpj, (const guchar*)_("Print"), GNOME_PRINT_DIALOG_COPIES));
+	SET_ICON (gpd);
 	gnome_print_dialog_set_copies(gpd, copies, collate);
 	switch (gtk_dialog_run(GTK_DIALOG(gpd)))
 	{
@@ -226,7 +231,9 @@ void on_print(GtkWidget* widget, void* data)
 	gnome_print_job_close(gpj);
 	if (do_preview)
 	{
-		gtk_widget_show (gnome_print_job_preview_new (gpj, (const guchar*)_("Preview")));
+		GtkWidget *preview = gnome_print_job_preview_new (gpj, (const guchar*)_("Preview"));
+		SET_ICON (preview);
+		gtk_widget_show (preview);
 	}
 	else
 	{
@@ -317,19 +324,13 @@ static bool on_key_press(GtkWidget* widget, GdkEventKey* ev, void *data)
 	return false;
 }
 
-static void on_prefs(GtkWidget* widget, void* data)
-{
-/*	GtkFontSelectionDialog* dlg = (GtkFontSelectionDialog*)gtk_font_selection_dialog_new("");
-	gtk_dialog_run(GTK_DIALOG(dlg));
-	gtk_widget_destroy(GTK_WIDGET(dlg));*/
-}
-
 static bool do_save_as_image(GtkWidget* widget, GtkFileSelection *fsel)
 {
 	const gchar* filename = gtk_file_selection_get_filename(fsel);
 	if (!filename || !strlen(filename) || filename[strlen(filename) - 1] == '/') {
 		GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (fsel), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
 															_("Please enter a file name,\nnot a directory"));
+		SET_ICON(message);
 		gtk_dialog_run (GTK_DIALOG (message));
 		gtk_widget_destroy (message);
 		return true;
@@ -342,6 +343,7 @@ static bool do_save_as_image(GtkWidget* widget, GtkFileSelection *fsel)
 	{
 		gchar * message = g_strdup_printf(_("File %s\nexists, overwrite?"), filename);
 		GtkDialog* Box = GTK_DIALOG(gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
+		SET_ICON(Box);
 		result = gtk_dialog_run(Box);
 		gtk_widget_destroy(GTK_WIDGET(Box));
 		g_free(message);
@@ -365,6 +367,7 @@ static bool do_save_as_image(GtkWidget* widget, GtkFileSelection *fsel)
 		} else {
 			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (fsel), GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, 
 																_("Please, install which and ps2eps!"));
+			SET_ICON(message);
 			gtk_dialog_run (GTK_DIALOG (message));
 			gtk_widget_destroy (message);
 		}
@@ -379,6 +382,7 @@ static bool do_save_as_image(GtkWidget* widget, GtkFileSelection *fsel)
 	else {
 		GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (fsel), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
 															_("Sorry, format not supported!"));
+		SET_ICON(message);
 		gtk_dialog_run (GTK_DIALOG (message));
 		gtk_widget_destroy (message);
 	}
@@ -399,18 +403,16 @@ void on_about(GtkWidget* widget, void* data)
 {
 	char * authors[]={"Jean Bréfort",NULL};
 	char * documentors[] = {NULL};
-	char * translators = _(\
-"Jean Bréfort <jean.brefort@ac-dijon.fr>: French\n\
-Christian Neumair <christian-neumair@web.de>: German\n\
-Costantino Ceoldo: Italian\n\
-Ben Luo: Chinese\n\
-Michał Sałaban: Polish"
-			);
-	GdkPixbuf* pixbuf = gdk_pixbuf_new_from_file ( DATADIR"/pixmaps/gchempaint_logo.png", NULL);
+	GdkPixbuf* pixbuf = gdk_pixbuf_new_from_file ( DATADIR"/"PACKAGE"/pixmaps/gchempaint_logo.png", NULL);
+	char *translator_credits = _("translator_credits");
 	GtkWidget* about = gnome_about_new(_("GChemPaint"), VERSION,
 										_("(C) 2001-2004 by Jean Bréfort"),
 										_("GChemPaint is a 2D chemical structures editor for Gnome"),
-										(const gchar**) authors, (const gchar**) documentors, translators, pixbuf);
+										(const gchar**) authors, (const gchar**) documentors,
+										(strcmp (translator_credits, "translator_credits") != 0 ? 
+											(const char *)translator_credits : NULL),
+										pixbuf);
+	SET_ICON(about);
 	if (pixbuf != NULL)
 		g_object_unref (pixbuf);
 	gtk_widget_show_all(about);
@@ -523,7 +525,6 @@ static GnomeUIInfo tool_bar [] = {
 	GNOMEUIINFO_END
 };
 
-static char* opt_filename = NULL;
 static bool bonobo_server_flag = false;
 struct poptOption options[] =
 {
@@ -583,6 +584,14 @@ int main(int argc, char *argv[])
 		l = l->next;
 	}
 	g_slist_free (formats);
+#ifndef GTK_IS_26
+	GError *error = NULL;
+#ifdef GNOME_OLD_VER
+	icon = gdk_pixbuf_new_from_file (DATADIR"/pixmaps/gchempaint.png", &error);
+#else
+	icon = gdk_pixbuf_new_from_file (DATADIR"/icons/hicolor/48x48/apps/gchempaint.png", &error);
+#endif
+#endif
 
 	if (bonobo_server_flag)
 	{
@@ -594,6 +603,7 @@ int main(int argc, char *argv[])
 		app = GNOME_APP(gnome_app_new(_("GChemPaint"), _("GChemPaint")));
 		gnome_app_create_menus(app, main_menu);
 		gnome_app_create_toolbar(app, tool_bar);
+		SET_ICON(app);
 		windowsmenu = GTK_MENU(windows_menu[0].widget->parent);
 		bar = gnome_appbar_new(true, true, GNOME_PREFERENCES_ALWAYS);
 		gnome_appbar_set_default(GNOME_APPBAR(bar), _("Ready."));
@@ -622,7 +632,9 @@ int main(int argc, char *argv[])
 		SubscriptBtn = glade_xml_get_widget(xml, "subscript");
 		SuperscriptBtn = glade_xml_get_widget(xml, "superscript");
 		FontBtn = glade_xml_get_widget(xml, "font");
+#ifdef GTK_IS_RECENT
 		gtk_toolbar_set_show_arrow(GTK_TOOLBAR (TextToolBar), false);
+#endif
 		gtk_widget_show_all (TextToolBar);
 		gnome_app_add_toolbar(app, GTK_TOOLBAR(widget), "texttools", BONOBO_DOCK_ITEM_BEH_NORMAL, BONOBO_DOCK_TOP, 2, 0, 0);
 		gtk_widget_set_sensitive(widget, false);
@@ -648,6 +660,10 @@ int main(int argc, char *argv[])
 
 		gtk_main();
 	}
+
+#ifndef GTK_IS_26
+	g_object_unref (icon);
+#endif
 		
 	return 0;
 }
