@@ -4,9 +4,9 @@
  * GChemPaint
  * texttool.cc 
  *
- * Copyright (C) 2002-2003
+ * Copyright (C) 2002-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -142,7 +142,6 @@ gcpTextTool::~gcpTextTool()
 
 bool gcpTextTool::OnClicked()
 {
-	void *func;
 	if (m_Active && ((m_pObject == NULL) || (m_pObject->GetType() != TextType) || (m_Active != m_pData->Items[m_pObject]->item_list->data)))
 		Unselect();
 	if (!m_pObject)
@@ -398,7 +397,7 @@ bool gcpTextTool::OnToggled(GtkToggleButton *btn)
 
 bool gcpTextTool::OnFont()
 {
-	GtkTextBuffer* buf ;
+	GtkTextBuffer* buf = NULL;
 	GtkTextIter start, end;
 	GtkWidget *dialog = gtk_font_selection_dialog_new("");
 	gtk_window_set_modal(GTK_WINDOW(dialog), true);
